diff --git a/Strategic/Assignments.cpp b/Strategic/Assignments.cpp
index 88de3db6..694ed1ac 100644
--- a/Strategic/Assignments.cpp
+++ b/Strategic/Assignments.cpp
@@ -2514,6 +2514,9 @@ UINT8 CalculateRepairPointsForRepairman(SOLDIERTYPE *pSoldier, UINT16 *pusMaxPts
return(0);
}
+ //JMich_SkillsModifiers: We should have the best repair kit in hands, so the effectiveness is 100 + kit's effectiveness.
+ ubKitEffectiveness = 100 + Item[pSoldier->inv[HANDPOS].usItem].RepairModifier;
+
// calculate effective repair rate (adjusted for drugs, alcohol, etc.)
usRepairPts = (UINT16) ((EffectiveMechanical( pSoldier ) * EffectiveDexterity( pSoldier, FALSE ) * (100 + ( 5 * EffectiveExpLevel( pSoldier) ) ) ) / ( gGameExternalOptions.ubRepairRateDivisor * gGameExternalOptions.ubAssignmentUnitsPerDay ));
@@ -2557,18 +2560,21 @@ UINT8 CalculateRepairPointsForRepairman(SOLDIERTYPE *pSoldier, UINT16 *pusMaxPts
usKitPts = ToolKitPoints( pSoldier );
// if kit(s) in extremely bad shape
+ //JMich_SkillsModifiers: Changed this to a divisor
if ( usKitPts < 25 )
{
- ubKitEffectiveness = 50;
+ //ubKitEffectiveness = 50;
+ ubKitEffectiveness /= 2;
}
// if kit(s) in pretty bad shape
else if ( usKitPts < 50 )
{
- ubKitEffectiveness = 75;
+ //ubKitEffectiveness = 75
+ ubKitEffectiveness = (ubKitEffectiveness * 3) / 4;
}
else
{
- ubKitEffectiveness = 100;
+ //ubKitEffectiveness = 100;
}
if (pSoldier->bSectorZ == 0)
@@ -6795,17 +6801,25 @@ void RepairMenuMvtCallback(MOUSE_REGION * pRegion, INT32 iReason )
void MakeSureToolKitIsInHand( SOLDIERTYPE *pSoldier )
{
- INT8 bPocket = 0;
+ //JMich_SkillModifiers: added bonus to see which is the maximum, and an extra pocket to store the highest bonus found so far.
+ INT8 bPocket = 0, bonus = -101, bToolkitPocket = NO_SLOT;
// if there isn't a toolkit in his hand
- if( !Item[pSoldier->inv[ HANDPOS].usItem].toolkit )
+ if( Item[pSoldier->inv[ HANDPOS].usItem].toolkit )
{
+ bonus = Item[pSoldier->inv[ HANDPOS].usItem].RepairModifier;
+ bToolkitPocket = HANDPOS;
+ }
// run through rest of inventory looking for toolkits, swap the first one into hand if found
// CHRISL: Changed to dynamically determine max inventory locations.
for (bPocket = SECONDHANDPOS; bPocket < NUM_INV_SLOTS; bPocket++)
{
- if( Item[pSoldier->inv[ bPocket ].usItem].toolkit )
+ if( Item[pSoldier->inv[ bPocket ].usItem].toolkit && Item[pSoldier->inv[ bPocket ].usItem].RepairModifier > bonus)
{
+ bonus = Item[pSoldier->inv[ bPocket ].usItem].RepairModifier;
+ bToolkitPocket = bPocket;
+ }
+ }
// HEADROCK HAM B2.8: These new conditions will create a bias for swapping an item out of
// our hand.
@@ -6816,14 +6830,10 @@ void MakeSureToolKitIsInHand( SOLDIERTYPE *pSoldier )
// Else, if the gun sling slot is free, and the item can go there, it will.
else if(UsingNewInventorySystem() && !pSoldier->inv[GUNSLINGPOCKPOS].exists() && CanItemFitInPosition(pSoldier, &pSoldier->inv[HANDPOS], GUNSLINGPOCKPOS, FALSE))
SwapObjs(pSoldier, HANDPOS, GUNSLINGPOCKPOS, TRUE);
- else if(!CanItemFitInPosition(pSoldier, &pSoldier->inv[HANDPOS], bPocket, FALSE))
+ else if(!CanItemFitInPosition(pSoldier, &pSoldier->inv[HANDPOS], bToolkitPocket, FALSE))
SwapObjs(pSoldier, HANDPOS, SECONDHANDPOS, TRUE);
- SwapObjs( pSoldier, HANDPOS, bPocket, TRUE );
- break;
+ SwapObjs( pSoldier, HANDPOS, bToolkitPocket, TRUE );
}
- }
- }
-}
BOOLEAN MakeSureMedKitIsInHand( SOLDIERTYPE *pSoldier )
diff --git a/Tactical/Interface Enhanced.cpp b/Tactical/Interface Enhanced.cpp
index c529c138..2fa385b1 100644
--- a/Tactical/Interface Enhanced.cpp
+++ b/Tactical/Interface Enhanced.cpp
@@ -2336,7 +2336,8 @@ void InternalInitEDBTooltipRegion( OBJECTTYPE * gpItemDescObject, UINT32 guiCurr
//////////////////// LOCKSMITH'S KIT
if (Item[ gpItemDescObject->usItem ].locksmithkit)
{
- swprintf( pStr, L"%s%s", szUDBGenSecondaryStatsTooltipText[ 10 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 10 ]);
+ swprintf( pStr, L"%s%s%d", szUDBGenSecondaryStatsTooltipText[ 10 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 10 ], (Item[ gpItemDescObject->usItem ].LockPickModifier > 0 ?
+ ( Item[ gpItemDescObject->usItem ].LockPickModifier * (*gpItemDescObject)[0]->data.objectStatus / 100 ) : Item[ gpItemDescObject->usItem ].LockPickModifier ) );
SetRegionFastHelpText( &(gUDBFasthelpRegions[ iFirstDataRegion + cnt ]), pStr );
MSYS_EnableRegion( &gUDBFasthelpRegions[ iFirstDataRegion + cnt ] );
cnt++;
@@ -2354,13 +2355,13 @@ void InternalInitEDBTooltipRegion( OBJECTTYPE * gpItemDescObject, UINT32 guiCurr
//////////////////// CROWBAR
if (Item[ gpItemDescObject->usItem ].crowbar)
{
- swprintf( pStr, L"%s%s", szUDBGenSecondaryStatsTooltipText[ 12 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 12 ]);
+ swprintf( pStr, L"%s%s%d", szUDBGenSecondaryStatsTooltipText[ 12 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 12 ], Item[ gpItemDescObject->usItem ].CrowbarModifier );
SetRegionFastHelpText( &(gUDBFasthelpRegions[ iFirstDataRegion + cnt ]), pStr );
MSYS_EnableRegion( &gUDBFasthelpRegions[ iFirstDataRegion + cnt ] );
cnt++;
}
- //////////////////// CROWBAR
+ //////////////////// METAL DETECTOR
if (Item[ gpItemDescObject->usItem ].metaldetector)
{
swprintf( pStr, L"%s%s", szUDBGenSecondaryStatsTooltipText[ 13 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 13 ]);
@@ -2408,7 +2409,7 @@ void InternalInitEDBTooltipRegion( OBJECTTYPE * gpItemDescObject, UINT32 guiCurr
//////////////////// TOOLKIT
if (Item[ gpItemDescObject->usItem ].toolkit)
{
- swprintf( pStr, L"%s%s", szUDBGenSecondaryStatsTooltipText[ 18 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 18 ]);
+ swprintf( pStr, L"%s%s%d", szUDBGenSecondaryStatsTooltipText[ 18 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 18 ], Item[ gpItemDescObject->usItem ].RepairModifier );
SetRegionFastHelpText( &(gUDBFasthelpRegions[ iFirstDataRegion + cnt ]), pStr );
MSYS_EnableRegion( &gUDBFasthelpRegions[ iFirstDataRegion + cnt ] );
cnt++;
@@ -2507,6 +2508,14 @@ void InternalInitEDBTooltipRegion( OBJECTTYPE * gpItemDescObject, UINT32 guiCurr
cnt++;
}
}
+ ///////////////////// DEFUSAL KIT
+ if ( Item[gpItemDescObject->usItem].DisarmModifier > 0)
+ {
+ swprintf( pStr, L"%s%s%d", szUDBGenSecondaryStatsTooltipText[ 30 ], szUDBGenSecondaryStatsExplanationsTooltipText[ 30 ], Item[gpItemDescObject->usItem].DisarmModifier);
+ SetRegionFastHelpText( &(gUDBFasthelpRegions[ iFirstDataRegion + cnt ]), pStr );
+ MSYS_EnableRegion( &gUDBFasthelpRegions[ iFirstDataRegion + cnt ] );
+ cnt++;
+ }
}
//////////////////////////////////////////////////////
@@ -5530,6 +5539,13 @@ void DrawSecondaryStats( OBJECTTYPE * gpItemDescObject )
cnt++;
}
}
+ ////////////////// DEFUSAL KIT
+ //JMich_SkillsModifiers: Still needs a picture, currently using the wirecutters.
+ if ( Item[gpItemDescObject->usItem].DisarmModifier > 0 )
+ {
+ BltVideoObjectFromIndex( guiSAVEBUFFER, guiItemInfoSecondaryIcon, 11, gItemDescGenSecondaryRegions[cnt].sLeft+sOffsetX, gItemDescGenSecondaryRegions[cnt].sTop+sOffsetY, VO_BLT_SRCTRANSPARENCY, NULL );
+ cnt++;
+}
}
void DrawWeaponValues( OBJECTTYPE * gpItemDescObject )
diff --git a/Tactical/Item Types.h b/Tactical/Item Types.h
index 547bcb57..0805b88e 100644
--- a/Tactical/Item Types.h
+++ b/Tactical/Item Types.h
@@ -1012,6 +1012,12 @@ typedef struct
// Flugente: food type
UINT32 foodtype;
+ //JMich_SkillModifiers: Adding new skill modifiers
+ INT8 LockPickModifier;
+ UINT8 CrowbarModifier;
+ UINT8 DisarmModifier;
+ INT8 RepairModifier;
+
} INVTYPE;
// CHRISL: Added new structures to handle LBE gear and the two new XML files that will be needed to deal
diff --git a/Tactical/Items.cpp b/Tactical/Items.cpp
index c8c35a54..d2f5de1d 100644
--- a/Tactical/Items.cpp
+++ b/Tactical/Items.cpp
@@ -11566,18 +11566,22 @@ INT8 FindCannon( SOLDIERTYPE * pSoldier )
INT8 FindUsableCrowbar( SOLDIERTYPE * pSoldier )
{
- INT8 bLoop;
+ //JMich_SkillModifiers: Adding a bonus check, to return the best crowbar, and modifying the return value.
+ INT8 bLoop, bonus, FoundCrowbar;
+ FoundCrowbar = NO_SLOT;
+ bonus = -101;
for (bLoop = 0; bLoop < (INT8) pSoldier->inv.size(); bLoop++)
{
if (pSoldier->inv[bLoop].exists() == true) {
- if ( Item[pSoldier->inv[bLoop].usItem].crowbar && pSoldier->inv[bLoop][0]->data.objectStatus >= USABLE )
+ if ( Item[pSoldier->inv[bLoop].usItem].crowbar && pSoldier->inv[bLoop][0]->data.objectStatus >= USABLE && Item[pSoldier->inv[bLoop].usItem].CrowbarModifier > bonus)
{
- return( bLoop );
+ bonus = Item[pSoldier->inv[bLoop].usItem].CrowbarModifier;
+ FoundCrowbar = bLoop;
}
}
}
- return( NO_SLOT );
+ return( FoundCrowbar );
}
OBJECTTYPE* FindAttachedBatteries( OBJECTTYPE * pObj )
@@ -11652,20 +11656,60 @@ INT8 FindCamoKit( SOLDIERTYPE * pSoldier )
}
return( NO_SLOT );
}
+//JMich_SkillModifiers: Adding a function to see if we have an item with disarm bonus
+INT8 FindDisarmKit( SOLDIERTYPE * pSoldier )
+{
+ INT8 bLoop, bonus, FoundKit;
+ FoundKit = NO_SLOT;
+ bonus = 0;
+
+ for (bLoop = 0; bLoop < (INT8) pSoldier->inv.size(); bLoop++)
+ {
+ if (pSoldier->inv[bLoop].exists() == true) {
+ if ( ( ( Item[pSoldier->inv[bLoop].usItem].DisarmModifier * pSoldier->inv[bLoop][0]->data.objectStatus ) / 100 ) > bonus )
+ {
+ bonus = Item[pSoldier->inv[bLoop].usItem].DisarmModifier * pSoldier->inv[bLoop][0]->data.objectStatus / 100;;
+ FoundKit = bLoop;
+ }
+ }
+ }
+ return( FoundKit );
+}
INT8 FindLocksmithKit( SOLDIERTYPE * pSoldier )
{
- INT8 bLoop;
+ //JMich_SkillModifiers: Adding a bonus check, to return the best LocksmithKit, and modifying the return value.
+ INT8 bLoop, bonus, FoundKit;
+ FoundKit = NO_SLOT;
+ bonus = -101;
for (bLoop = 0; bLoop < (INT8) pSoldier->inv.size(); bLoop++)
{
if (pSoldier->inv[bLoop].exists() == true) {
if (Item[pSoldier->inv[bLoop].usItem].locksmithkit )
{
- return( bLoop );
+ //JMich_SkillModifiers: If the locksmith kit has a bonus, reduce it based on the status, so we use the best bonus.
+ if (Item[pSoldier->inv[bLoop].usItem].LockPickModifier > 0 )
+ {
+ if ( ( Item[pSoldier->inv[bLoop].usItem].LockPickModifier * pSoldier->inv[bLoop][0]->data.objectStatus / 100 ) > bonus )
+ {
+ bonus = ( Item[pSoldier->inv[bLoop].usItem].LockPickModifier * pSoldier->inv[bLoop][0]->data.objectStatus / 100 );
+ FoundKit = bLoop;
+ }
+
+ }
+ //JMich_SkillModifiers: If on the other hand the locksmith is a shoddy one, keep that penalty regardless of status.
+ else
+ {
+ if ( Item[pSoldier->inv[bLoop].usItem].LockPickModifier > bonus )
+ {
+ bonus = Item[pSoldier->inv[bLoop].usItem].LockPickModifier;
+ FoundKit = bLoop;
+ }
+}
}
}
}
- return( NO_SLOT );
+ return( FoundKit );
}
INT8 FindWalkman( SOLDIERTYPE * pSoldier )
{
diff --git a/Tactical/Items.h b/Tactical/Items.h
index 76807524..ef5faba7 100644
--- a/Tactical/Items.h
+++ b/Tactical/Items.h
@@ -384,6 +384,7 @@ BOOLEAN IsRemoteDetonatorAttached( OBJECTTYPE * pObj ); // Flugente: no more ne
OBJECTTYPE* FindAttachedBatteries( OBJECTTYPE * pObj );
INT8 FindMedKit( SOLDIERTYPE * pSoldier );
INT8 FindFirstAidKit( SOLDIERTYPE * pSoldier );
+INT8 FindDisarmKit( SOLDIERTYPE * pSoldier ); //JMich_SkillsModifiers: Added function to check for disarm bonus
INT8 FindLocksmithKit( SOLDIERTYPE * pSoldier );
INT8 FindCamoKit( SOLDIERTYPE * pSoldier );
INT8 FindWalkman( SOLDIERTYPE * pSoldier );
diff --git a/Tactical/SkillCheck.cpp b/Tactical/SkillCheck.cpp
index b8ae8ba0..e62539d3 100644
--- a/Tactical/SkillCheck.cpp
+++ b/Tactical/SkillCheck.cpp
@@ -256,7 +256,6 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
INT32 iSkill;
INT32 iChance, iReportChance;
INT32 iRoll, iMadeItBy;
- INT8 bSlot;
INT32 iLoop;
SOLDIERTYPE * pTeamSoldier;
INT8 bBuddyIndex;
@@ -268,6 +267,7 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
{
case LOCKPICKING_CHECK:
case ELECTRONIC_LOCKPICKING_CHECK:
+ INT8 bSlot;
fForceDamnSound = TRUE;
@@ -321,7 +321,16 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
// this should never happen, but might as well check...
iSkill = 0;
}
- iSkill = iSkill * pSoldier->inv[bSlot][0]->data.objectStatus / 100;
+ else
+ {
+ //JMich_SkillsModifiers: Modifying the skill by the bonus from the lockpick, then reducing due to status
+ iSkill += Item[pSoldier->inv[bSlot].usItem].LockPickModifier;
+ }
+ //JMich_SkillsModifiers: If skill goes negative due to crappy lockpicks, the status of them doesn't matter.
+ if (iSkill > 0)
+ {
+ iSkill = (iSkill * pSoldier->inv[bSlot][0]->data.objectStatus) / 100;
+ }
break;
case ATTACHING_DETONATOR_CHECK:
case ATTACHING_REMOTE_DETONATOR_CHECK:
@@ -420,10 +429,15 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
break;
}
}
-
iSkill += EffectiveDexterity( pSoldier, FALSE ) * 2;
iSkill += EffectiveExpLevel( pSoldier ) * 10;
iSkill = iSkill / 10; // bring the value down to a percentage
+ //JMich_SkillModifiers: Adding a Disarm Trap bonus
+ bSlot = FindDisarmKit( pSoldier);
+ if (bSlot != NO_SLOT)
+ {
+ iSkill += Item[pSoldier->inv[bSlot].usItem].DisarmModifier * pSoldier->inv[bSlot][0]->data.objectStatus / 100;
+ }
// SANDRO - STOMP traits - Demolitions trait removing traps bonus
if ( gGameOptions.fNewTraitSystem )
@@ -468,6 +482,12 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
iSkill += EffectiveDexterity( pSoldier, FALSE ) * 2;
iSkill += EffectiveExpLevel( pSoldier ) * 10;
iSkill = iSkill / 10; // bring the value down to a percentage
+ //JMich_SkillModifiers: Adding a Disarm Trap bonus
+ bSlot = FindDisarmKit( pSoldier);
+ if (bSlot != NO_SLOT)
+ {
+ iSkill += Item[pSoldier->inv[bSlot].usItem].DisarmModifier * pSoldier->inv[bSlot][0]->data.objectStatus / 100;
+ }
// penalty based on poor wisdom
iSkill -= (100 - EffectiveWisdom( pSoldier ) ) / 5;
@@ -495,7 +515,16 @@ INT32 SkillCheck( SOLDIERTYPE * pSoldier, INT8 bReason, INT8 bChanceMod )
case OPEN_WITH_CROWBAR:
// Add for crowbar...
- iSkill = EffectiveStrength( pSoldier, FALSE ) + 20;
+ //JMich_SkillModifiers: Changing the +20 to the crowbar's bonus.
+ bSlot = FindUsableCrowbar( pSoldier );
+ if (bSlot != NO_SLOT)
+ {
+ iSkill = EffectiveStrength( pSoldier, FALSE ) + Item[pSoldier->inv[bSlot].usItem].CrowbarModifier;
+ }
+ else //how are we trying to force with a crowbar, without having one??
+ {
+ iSkill = 0;
+ }
fForceDamnSound = TRUE;
break;
diff --git a/Utils/XML_Items.cpp b/Utils/XML_Items.cpp
index 65d80e59..646b5390 100644
--- a/Utils/XML_Items.cpp
+++ b/Utils/XML_Items.cpp
@@ -269,7 +269,12 @@ itemStartElementHandle(void *userData, const XML_Char *name, const XML_Char **at
strcmp(name, "ItemFlag") == 0 ||
strcmp(name, "FoodType") == 0 ||
- strcmp(name, "fFlags") == 0 ))
+ strcmp(name, "fFlags") == 0 ||
+ //JMich_SkillModifiers: Adding new flags
+ strcmp(name, "LockPickModifier") == 0 ||
+ strcmp(name, "CrowbarModifier") == 0 ||
+ strcmp(name, "DisarmModifier") == 0 ||
+ strcmp(name, "RepairModifier") == 0 ))
{
pData->curElement = ELEMENT_PROPERTY;
//DebugMsg(TOPIC_JA2, DBG_LEVEL_3, String("itemStartElementHandle: going into element, name = %s",name) );
@@ -1349,8 +1354,28 @@ itemEndElementHandle(void *userData, const XML_Char *name)
pData->curElement = ELEMENT;
pData->curItem.foodtype = (UINT32) atol(pData->szCharData);
}
+ //JMich_SkillsModifiers: Parse new values
+ else if(strcmp(name, "LockPickModifier") == 0)
+ {
+ pData->curElement = ELEMENT;
+ pData->curItem.LockPickModifier = (INT8) atol(pData->szCharData);
+ }
+ else if(strcmp(name, "CrowbarModifier") == 0)
+ {
+ pData->curElement = ELEMENT;
+ pData->curItem.CrowbarModifier = (UINT8) atol(pData->szCharData);
+ }
+ else if(strcmp(name, "DisarmModifier") == 0)
+ {
+ pData->curElement = ELEMENT;
+ pData->curItem.DisarmModifier = (UINT8) atol(pData->szCharData);
+ }
+ else if(strcmp(name, "RepairModifier") == 0)
+ {
+ pData->curElement = ELEMENT;
+ pData->curItem.RepairModifier = (INT8) atol(pData->szCharData);
+ }
-
pData->maxReadDepth--;
}
@@ -1969,6 +1994,12 @@ BOOLEAN WriteItemStats()
FilePrintf(hFile,"\t\t%d\r\n", Item[cnt].foodtype );
+ //JMich_SkillModifiers: Adding the values here as well
+ FilePrintf(hFile, "\t\t%d\r\n", Item[cnt].LockPickModifier );
+ FilePrintf(hFile, "\t\t%d\r\n", Item[cnt].CrowbarModifier );
+ FilePrintf(hFile, "\t\t%d\r\n", Item[cnt].DisarmModifier );
+ FilePrintf(hFile, "\t\t%d\r\n", Item[cnt].RepairModifier );
+
// Flugente poison system
FilePrintf(hFile,"\t\t%d\r\n", Item[cnt].bPoisonPercentage );
diff --git a/Utils/_ChineseText.cpp b/Utils/_ChineseText.cpp
index 2553ba16..9029203e 100644
--- a/Utils/_ChineseText.cpp
+++ b/Utils/_ChineseText.cpp
@@ -1638,7 +1638,7 @@ STR16 pAssignmentStrings[] =
L"教练", // training a teammate
L"学员", // being trained by someone else
L"工作", // L"Staff", // operating a strategic facility //ham3.6
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"休息", //L"Rest",// Resting at a facility //ham3.6
L"死亡", // dead
L"无力中", // abbreviation for incapacitated
@@ -1723,7 +1723,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"教练",
L"学员",
L"设施职员",
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"在设施里休养",
L"休息",
L"无力中",
@@ -2926,12 +2926,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6674,7 +6674,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"环境",
L"工作人员",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"休息",
L"修理物品",
L"修理%s", // Vehicle name inserted here
@@ -7066,10 +7066,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|急|救|包",
L"|医|药|箱",
L"|破|锁|炸|弹",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7084,15 +7085,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \n该物品是电子产品,含有复杂电路。\n \n电子产品在维修者没有电子技能时很难被修复\n。",
L"\n \n将该物品佩戴于面部时,使用者不受任何\n有毒气体的伤害。\n \n然而有些腐蚀性气体可以通过腐蚀\n作用穿过这个面罩。",
L"\n \n该物品需要电池。没有安装电池时使用者不\n能使用这个物品的主要功能。\n \n只要把所需电池安装于该物品的附件栏即可\n(步骤与将瞄准镜安装在步枪上一样)。",
- L"\n \n该物品能够用于开锁。\n \n(用技巧)开锁不会发出声音,但是开稍微复\n杂一些的锁需要足够的机械能力。",
+ L"\n \n该物品能够用于开锁。\n \n(用技巧)开锁不会发出声音,但是开稍微复\n杂一些的锁需要足够的机械能力。 This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \n该物品能够绞断铁丝网。\n \n使用此物品,佣兵可以快速穿越用铁丝网封锁的地区,以便\n包围敌人!",
- L"\n \n该物品能够用于破坏锁具。\n \n破坏锁具需要很大的力量,既会发出很大的\n噪音,也很耗费佣兵的体力。但是在没有出色\n的技巧和复杂的工具时,用力量破坏锁具也是明智\n之举。",
+ L"\n \n该物品能够用于破坏锁具。\n \n破坏锁具需要很大的力量,既会发出很大的\n噪音,也很耗费佣兵的体力。但是在没有出色\n的技巧和复杂的工具时,用力量破坏锁具也是明智\n之举。 This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \n该物品能够探测地下的金属物品。\n \n显然其主要用于在没有肉眼识别地雷的能力时探测地\n雷。但是你也可以用它发现埋在地下的宝藏。",
L"\n \n该物品能够用来引爆已经安装远程爆破引信的炸弹\n。\n \n先放置炸弹,时机一到再用它引爆。",
L"\n \n安装该引信的爆破物设置完成后\n,可以被远程控制器引爆。\n \n远程引信是设置陷阱的不二选择,因为它只会在你需要\n它爆炸的时候被引爆,而且留给你足够的时间跑\n开!",
L"\n \n安装该引信的爆破物设置完成后\n,该引信会开始倒数计时,并在设置的时间后\n被引爆。\n \n计时引信便宜并且易于安装,但是你必须给它\n设定合适的时间以便你能够跑开!",
L"\n \n该物品承有汽油。\n \n在你需要加油时十分有用。",
- L"\n \n工具箱内装有各种能用来修复其他物品的工具。\n \n安排佣兵进行修复工作时该佣兵必须持有工具\n箱。",
+ L"\n \n工具箱内装有各种能用来修复其他物品的工具。\n \n安排佣兵进行修复工作时该佣兵必须持有工具\n箱。 This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \n将该物品佩戴于面部时,\n可以利用热成像原理,\n发现墙壁后方的敌人。",
L"\n \n这种功能强大的仪器利用X光搜索敌军。\n \n它可以在短时间内暴露一定范围中的敌人位置。\n请远离生殖器使用!",
L"\n \n该物品装有饮用水。\n \n口渴时饮用。",
@@ -7100,10 +7101,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \n这一战场的基础急救包提供了基本的医疗用品。\n \n可以被用来包扎受伤的角色以止血。\n \n如需要回复生命,使用名副其实的医药箱,并辅以大量的休息。",
L"\n \n这是名副其实的医药箱,可以用于外科手术或其他复杂的治疗。\n \n安排佣兵进行医疗工作时,该佣兵必须持有医\n药箱。",
L"\n \n该物品能够用于爆破锁具。\n \n使用它需要爆破技能以避免过早引爆。\n \n使用炸药是一个相对简单的破锁手段,但是会\n发出很大噪音,并且对于大部分佣兵来说过于\n危险。",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_DutchText.cpp b/Utils/_DutchText.cpp
index ccc8ab85..f8cd620b 100644
--- a/Utils/_DutchText.cpp
+++ b/Utils/_DutchText.cpp
@@ -1634,7 +1634,7 @@ STR16 pAssignmentStrings[] =
L"Trainer", // training a teammate
L"Student", // being trained by someone else
L"Staff", // operating a strategic facility // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Rest", // Resting at a facility // TODO.Translate
L"Dood", // dead
L"Uitgesc.", // abbreviation for incapacitated
@@ -1719,7 +1719,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Trainer", // training a teammate
L"Student", // being trained by someone else
L"Facility Staff", // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Resting at Facility", // TODO.Translate
L"Dood", // dead
L"Uitgesc.", // abbreviation for incapacitated
@@ -2923,12 +2923,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6670,7 +6670,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Staff",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Rest",
L"Repair Items",
L"Repair %s", // Vehicle name inserted here
@@ -7062,10 +7062,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|F|i|r|s|t |A|i|d |K|i|t",
L"|M|e|d|i|c|a|l |K|i|t",
L"|L|o|c|k |B|o|m|b",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7080,15 +7081,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number", // TODO.Translate
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7096,10 +7097,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis is a basic field medical kit, containing\nitems required to provide basic medical aid.\n \nIt can be used to bandage wounded characters\nand prevent bleeding.\n \nFor actual healing, use a proper Medical Kit\nand/or plenty of rest.",
L"\n \nThis is a proper medical kit, which can\nbe used in surgery and other serious medicinal\npurposes.\n \nMedical Kits are always required when setting\na character to Doctoring duty.",
L"\n \nThis item can be used to blast open locked\ndoors and containers.\n \nExplosives skill is required to avoid\npremature detonation.\n \nBlowing locks is a relatively easy way of quickly\ngetting through locked doors. However,\nit is very loud, and dangerous to most characters.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_EnglishText.cpp b/Utils/_EnglishText.cpp
index 33f67bae..dad7a4bc 100644
--- a/Utils/_EnglishText.cpp
+++ b/Utils/_EnglishText.cpp
@@ -2927,11 +2927,11 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
// added by Flugente to display health and poisoning
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -7058,6 +7058,7 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t",
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7072,15 +7073,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ",
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ",
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n\nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ",
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7092,6 +7093,7 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ",
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_FrenchText.cpp b/Utils/_FrenchText.cpp
index f562db36..2affd8e7 100644
--- a/Utils/_FrenchText.cpp
+++ b/Utils/_FrenchText.cpp
@@ -1637,7 +1637,7 @@ STR16 pAssignmentStrings[] =
L"Entraîneur", // training a teammate
L"Elève", // being trained by someone else
L"Exploitation", // operating a strategic facility
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Repos", // Resting at a facility
L"Mort(e)", // dead
L"Incap.", // abbreviation for incapacitated
@@ -1722,7 +1722,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Entraîneur",
L"Elève",
L"Exploitation infras.",
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Repos infras.",
L"Mort(e)",
L"Incap.",
@@ -2925,12 +2925,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6647,7 +6647,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Equipe",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Reste",
L"Réparer les objets",
L"Réparer %s", // Vehicle name inserted here
@@ -7037,10 +7037,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|T|r|o|u|s|s|e |d|e |1|e|r |s|o|i|n|s",
L"|T|r|o|u|s|s|e |d|e |s|o|i|n|s",
L"|B|o|m|b|e |p|o|u|r |s|e|r|r|u|r|e |d|e |p|o|r|t|e",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7055,15 +7056,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nCet objet est de nature électronique, et contient des\ncircuits complexes.\n \nLes objets électroniques sont intrinsèquement plus\ndifficiles à réparer, d'autant plus si vous n'avez pas\nles compétences nécessaires.",
L"\n \nLorsque cet objet est porté sur le visage, il le protègera\nde tous les gaz nocifs.\n \nNotez que certains gaz sont corrosifs, et pourrait bien\npénétrer à travers le masque...",
L"\n \nCet objet requière des piles. Sans les piles vous ne pouvez pas\nactiver ces principales caractéristiques.\n \nPour utiliser un jeu de piles, attachez-les à cette objet\ncomme si vous m'étiez une lunette de visée à votre arme.",
- L"\n \nCet objet peut être utilisé pour crocheter des portes\nou des containeurs vérouillés.\n \nLe crochetage est silencieux, mais nécessite des\ncompétences en Mécanique.",
+ L"\n \nCet objet peut être utilisé pour crocheter des portes\nou des containeurs vérouillés.\n \nLe crochetage est silencieux, mais nécessite des\ncompétences en Mécanique. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number", // TODO.Translate
L"\n \nCet objet peut être utilisé pour couper les clôtures de fil.\n \nCela autorise le mercenaire a passé à travers des zones\nsécurisés, pour éventuellement surprendre l'ennemi !",
- L"\n \nCet objet peut être utilisé pour frapper des portes\nou des containeurs vérouillés.\n \nFrapper des serrures requière une grande Force,\ngénère beaucoup de bruits, et peut facilement\nvous épuisez. Cependant, c'est une bonne façon\nd'ouvrir une serrure sans avoir des talents en\nMécaniques ou des outils adéquates.",
+ L"\n \nCet objet peut être utilisé pour frapper des portes\nou des containeurs vérouillés.\n \nFrapper des serrures requière une grande Force,\ngénère beaucoup de bruits, et peut facilement\nvous épuisez. Cependant, c'est une bonne façon\nd'ouvrir une serrure sans avoir des talents en\nMécaniques ou des outils adéquates. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nCet objet peut être utilisé pour détecter des objets métalliques\nenfouis sous terre.\n \nNaturellement, sa fonction première est de détecter les mines\nsans que vous ayez les compétences nécessaires pour les repérer\nà l'oeil nu.\n \nPeut-être trouverez-vous certains trésors cachés...",
L"\n \nCet objet peut être utilisé pour faire exploser une bombe\nqui aura été amorçée par un détonateur.\n \nPlantez la bombe en 1er, puis utilisez votre Déclencheur\nà distance pour l'activer quand c'est le bon moment.",
L"\n \nQuand il est attaché à un dispositif explosif et positionné\ndans le bon sens, ce détonateur peut être déclenché par un\ndétonateur (séparé) à distance.\n \nLes détonateurs à distance sont excellent pour faire des\npièges, car ils se déclenchent quand vous le souhaitez.\n \nDe plus, vous avez tout le temps pour déguerpir !",
L"\n \nQuand il est attaché à un dispositif explosif et positionné\ndans le bon sens, ce détonateur va lancer un compte à\nrebours défini, et explosera quand le temps sera écoulé.\n \nCes détonateurs avec minuterie sont pas chers et facile à\ninstaller, mais vous aurez besoin de temps pour pouvoir\ndéguerpir de là !",
L"\n \nCet objet contient de l'essence.\n \nIl pourrait arrivé à point nommé si vous aviez besoin\nde remplir un réservoir d'essence...",
- L"\n \nCet objet contient divers outils qui peuvent être utilisés\npour réparer d'autres objets.\n \nUne trousse à outil est toujours nécessaire lorsque vous\nêtes en mission de Réparation.",
+ L"\n \nCet objet contient divers outils qui peuvent être utilisés\npour réparer d'autres objets.\n \nUne trousse à outil est toujours nécessaire lorsque vous\nêtes en mission de Réparation. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nQuand équipé sur le visage, cet objet donne la capacité de\nrepérer les ennemis à travers les murs, grâce à leur\nsignature thermique.",
L"\n \nCe merveilleux dispositif peut être utilisé pour repérer\nles ennemis en utilisant les rayons X.\n \nCela révelera tous les ennemis à une certaine distance\npour une courte période de temps.\n \nGardez cela loin de vos organes reproductifs !",
L"\n \nCet objet contient de l'eau potable bien fraiche.\nA utillisé lorsque vous êtes assoiffé.",
@@ -7071,10 +7072,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nIl s'agit d'un kit médical basic, contenant les ustensibles\nrequis pour faire une intervention médicale basic.\n \nIl peut être utilisé pour soigner un mercenaire blessé et\nempêcher le saignement.\n \nPour une guérison optimale, utlisez une véritable trousse\nde soins et/ou beaucoup de repos.",
L"\n \nIl s'agit d'un kit médicale complet, qui peut être utilisé\npour une opération chirurgicale ou autre cas sérieux.\n \nUne trousse de soins est toujours nécessaire lorsque vous\nêtes en mission de Docteur.",
L"\n \nCet objet peut être utilisé pour faire sauter les portes\nou containeurs vérouillés.\n \nDes compétences en explosion sont nécessaire pour éviter\nune explosion prématurée.\n \nExploser les serrures est relativement facile et rapide\nà faire. Cependant, c'est très bruyant et dangereux pour\nla plupart des mercernaires.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_GermanText.cpp b/Utils/_GermanText.cpp
index 69daaae9..e93c97e0 100644
--- a/Utils/_GermanText.cpp
+++ b/Utils/_GermanText.cpp
@@ -2930,11 +2930,11 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Stolperdraht-Hierarchie (1 - 4) und das Netzwerk (A - D):",
// added by Flugente to display health and poisoning
- L"Gesundheit: %d/%d\n Gift: %d/%d\Ausdauer: %d/%d\Moral: %s",
+ L"Gesundheit: %d/%d\nGift: %d/%d\nAusdauer: %d/%d\nMoral: %s",
// added by Flugente to display food status
- L"Gesundheit: %d/%d\Ausdauer: %d/%d\Moral: %s\nWasser: %d%s\nEssen: %d%s",
- L"Gesundheit: %d/%d\n Gift: %d/%d\Ausdauer: %d/%d\Moral: %s\nWasser: %d%s\nEssen: %d%s",
+ L"Gesundheit: %d/%d\nAusdauer: %d/%d\nMoral: %s\nWasser: %d%s\nEssen: %d%s",
+ L"Ges.: %d/%d\nGift: %d/%d\nAusd.: %d/%d\nMoral: %s\nWasser: %d%s\nEssen: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6794,7 +6794,7 @@ STR16 szUDBGenAmmoStatsExplanationsTooltipText[]=
L"\n \nBestimmt eine verhältnismäßige Zunahme des Schadenspotentials,\nsobald die Kugel die Rüstung des Ziels\ndurchbricht und den Körper dahinter trifft.\n \nWerte über 1.0 erhöhen, Werte unter 1.0 reduzieren das Schadenspotential\nder durchbrochenen Kugel.\n \nHöher ist besser.",
L"\n \nEin Multiplikator zum Schadenspotential der Kugel,\nder vor dem Treffen des Zieles angewandt wird.\n \nWerte über 1.0 erhöhen, Werte unter 1.0 reduzieren den Schaden.\n \nHöher ist besser.",
L"\n \nProzentuale zusätzliche Hitze\ndurch diese Munitionsart.\n \nNiedriger ist besser.",
- L"\n \Gibt die Anzahl in Prozent an,\nob der eingetretene Schaden einer Kugel auch eine Vergiftung verursacht.",
+ L"\n \nGibt die Anzahl in Prozent an,\nob der eingetretene Schaden einer Kugel auch eine Vergiftung verursacht.",
};
STR16 szUDBGenExplosiveStatsTooltipText[]=
@@ -6885,6 +6885,7 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|N|a|h|r|u|n|g",
L"|M|u|n|i|t|i|o|n|s|g|u|r|t",
L"|M|u|n|i|t|i|o|n|s|w|e|s|t|e",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -6899,15 +6900,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nDieser Gegenstand ist Elektronik pur und beinhaltet\nkomplexe Schaltungen.\n \nElektronische Gegenstände sind von Natur aus schwer\nzu reparieren noch schwieriger ohne elektronische Fähigkeiten.",
L"\n \nWenn dieser Gegenstand am Gesicht der Person getragen wird,\nwird Sie von allen schädlichen Gasen beschützt.\n \nEinige Gase sind ätzend und können sich\ndurch die Gasmaske fressen!",
L"\n \nDieser Gegenstand benötigt Batterien. Ohne Batterien,\nkönnen seine primären Fähigkeiten nicht aktiviert werden.\n \nUm seine Fähigkeiten zu aktivieren\nbefestige Batterien an ihm.",
- L"\n \nDieser Gegenstand kann kann dazu benutzt werden verschlossene\nTüren oder Behälter zu öffnen.\n \nSchlösser knacken ist leise, doch es benötigt\nreichlich technische Fähigkeiten \nauch für die einfachsten Schlösser.",
+ L"\n \nDieser Gegenstand kann kann dazu benutzt werden verschlossene\nTüren oder Behälter zu öffnen.\n \nSchlösser knacken ist leise, doch es benötigt\nreichlich technische Fähigkeiten \nauch für die einfachsten Schlösser. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nDieser Gegenstand kann dazu benutzt werden Zäune zu zertrennen.\n \nDas ermöglicht einer Person schnell in abgezäuntes Gebiet\neinzudringen und den Feind möglicherweise zu überraschen!",
- L"\n \nDieser Gegenstand kann kann zum zerschlagen von verschlossenen\nTÜren oder Behälter benutzt werden.\n \nDas Zerschlagen von Schlössern benötigt reichlich Stärke,\nerzeugt eine Menge Lärm und bringt\neine Person schnell zur Ermüdung. Jedoch ist eine guter\nWeg hinter verschlossenes zu gelagen ohne\nhöhere Fertigkeiten oder\nkomplizierte Werkzeuge zu besitzen.",
+ L"\n \nDieser Gegenstand kann kann zum zerschlagen von verschlossenen\nTÜren oder Behälter benutzt werden.\n \nDas Zerschlagen von Schlössern benötigt reichlich Stärke,\nerzeugt eine Menge Lärm und bringt\neine Person schnell zur Ermüdung. Jedoch ist eine guter\nWeg hinter verschlossenes zu gelagen ohne\nhöhere Fertigkeiten oder\nkomplizierte Werkzeuge zu besitzen. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nDieser Gegenstand kann metallische Objekte\nim Boden aufspüren.\n \nSeine Funktion ist das aufspüren\nvon Minen ohne die nötigen Fähigkeiten zu besitzen diese\nmit blosen Auge zu erkennen.\n \nVielleicht finden Sie aber auch vergrabene Schätze.",
L"\n \nDieser Gegenstand kann dazu benutzt werden eine Bombe\nwelche mit einem Fernzünder versehen wurde zu zünden.\n \nZu erst setzt die Bombe, dann benutze den\nFernauslöer um sie zu zünden wenn\ndie richtige Zeit ist.",
L"\n \nWenn an einer Sprengstoffeinheit angebracht und eingestellt\n kann der Zünder durch eine\n separate Fernsteuerung ausgelöst werden.\n \nFernzünder sind bestens geeignet um Fallen zu stellen,\nweil Sie erst dann explodieren wenn sie es sollen.\n \nDarüber hinaus hat man genüge Zeit in Deckung zu gehen!",
L"\n \nWenn an einer Sprengstoffeinheit angebracht und eingestellt\n zählt der Zünder von der eingegeben\nMenge an Zeit nach unten und explodiert \nwenn die Zeit abgelaufen ist.\n \nZeitzünder sind billig und einfach zu Installieren,\naber sie müssen so eingestellt werden umd\nsich selbst rechtzeitig in Deckung zu bringen!",
L"\n \nDieser Gegenstand enthält Benzin.\n \nEs könnte praktisch sein\nwenn man einen Benzintank findet.",
- L"\n \nDieser Gegenstand enthält verschiedene Gerätschaften die dazu\nbenutzt werden können andere Gegenstände zu reparieren.\n \nEin Werkzeugkasten wird dafür benötigt, wenn \neinem Söldner die Aufgabe Reparieren zugewiesen wird.",
+ L"\n \nDieser Gegenstand enthält verschiedene Gerätschaften die dazu\nbenutzt werden können andere Gegenstände zu reparieren.\n \nEin Werkzeugkasten wird dafür benötigt, wenn \neinem Söldner die Aufgabe Reparieren zugewiesen wird. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWenn ans Gesicht angebracht, bietet der Gegenstand die Möglichkeit\nPersonen durch Wände zu sehen,\ndank ihrer Wärmestrahlung.",
L"\n \nDieses mächtige Gerät kann dazu benutzt werden\nnach Personen zu suchen.\n \nEs zeigt alle Personen innerhalb eines bestimmten Radius\nfür einen kurzen Zeitraum.\n \nVon Geschlechtsorganen fernhalten!",
L"\n \nDieser Gegenstand enthält frisches Wasser.\nGebrauchen Sie es wenn Sie durstig sind.",
@@ -6919,6 +6920,7 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nMan kann das essen.",
L"\n \nEin externer Munitionsgurt für MGs.",
L"\n \nIn diese Weste passen auch Munitionsgurte.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_ItalianText.cpp b/Utils/_ItalianText.cpp
index c12e0405..28d69107 100644
--- a/Utils/_ItalianText.cpp
+++ b/Utils/_ItalianText.cpp
@@ -1630,7 +1630,7 @@ STR16 pAssignmentStrings[] =
L"Istrutt.", // training a teammate
L"Studente", // being trained by someone else
L"Staff", // operating a strategic facility // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Rest", // Resting at a facility // TODO.Translate
L"Morto", // dead
L"Incap.", // abbreviation for incapacitated
@@ -1715,7 +1715,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Allenatore",
L"Studente",
L"Facility Staff", // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Resting at Facility", // TODO.Translate
L"Morto",
L"Incap.",
@@ -2918,12 +2918,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6657,7 +6657,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Staff",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Rest",
L"Repair Items",
L"Repair %s", // Vehicle name inserted here
@@ -7049,10 +7049,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|F|i|r|s|t |A|i|d |K|i|t",
L"|M|e|d|i|c|a|l |K|i|t",
L"|L|o|c|k |B|o|m|b",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7067,15 +7068,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7083,10 +7084,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis is a basic field medical kit, containing\nitems required to provide basic medical aid.\n \nIt can be used to bandage wounded characters\nand prevent bleeding.\n \nFor actual healing, use a proper Medical Kit\nand/or plenty of rest.",
L"\n \nThis is a proper medical kit, which can\nbe used in surgery and other serious medicinal\npurposes.\n \nMedical Kits are always required when setting\na character to Doctoring duty.",
L"\n \nThis item can be used to blast open locked\ndoors and containers.\n \nExplosives skill is required to avoid\npremature detonation.\n \nBlowing locks is a relatively easy way of quickly\ngetting through locked doors. However,\nit is very loud, and dangerous to most characters.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_PolishText.cpp b/Utils/_PolishText.cpp
index 55dcd873..9ec91e0d 100644
--- a/Utils/_PolishText.cpp
+++ b/Utils/_PolishText.cpp
@@ -1645,7 +1645,7 @@ STR16 pAssignmentStrings[] =
L"Instruk.", // training a teammate
L"Uczeń", // being trained by someone else
L"Staff", // operating a strategic facility // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Rest", // Resting at a facility // TODO.Translate
L"Nie żyje", // dead
L"Obezwł.", // abbreviation for incapacitated
@@ -1730,7 +1730,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Instruktor",
L"Uczeń",
L"Facility Staff", // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Resting at Facility", // TODO.Translate
L"Nie żyje",
L"Obezwładniony",
@@ -2933,12 +2933,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6669,7 +6669,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Staff",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Odpoczywa"
L"Naprawa ekwipunku",
L"Naprawa %s",
@@ -7061,10 +7061,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|F|i|r|s|t |A|i|d |K|i|t",
L"|M|e|d|i|c|a|l |K|i|t",
L"|L|o|c|k |B|o|m|b",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7079,15 +7080,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7095,10 +7096,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis is a basic field medical kit, containing\nitems required to provide basic medical aid.\n \nIt can be used to bandage wounded characters\nand prevent bleeding.\n \nFor actual healing, use a proper Medical Kit\nand/or plenty of rest.",
L"\n \nThis is a proper medical kit, which can\nbe used in surgery and other serious medicinal\npurposes.\n \nMedical Kits are always required when setting\na character to Doctoring duty.",
L"\n \nThis item can be used to blast open locked\ndoors and containers.\n \nExplosives skill is required to avoid\npremature detonation.\n \nBlowing locks is a relatively easy way of quickly\ngetting through locked doors. However,\nit is very loud, and dangerous to most characters.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_RussianText.cpp b/Utils/_RussianText.cpp
index 3571c0d8..dbb7bfb1 100644
--- a/Utils/_RussianText.cpp
+++ b/Utils/_RussianText.cpp
@@ -1638,7 +1638,7 @@ STR16 pAssignmentStrings[] =
L"Тренер", // training a teammate
L"Ученик", // being trained by someone else
L"Штат", // operating a strategic facility //Staff
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Отдых", // Resting at a facility //Rest
L"Мертв", // dead
L"Недеесп.", // abbreviation for incapacitated
@@ -1723,7 +1723,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Тренер",
L"Ученик",
L"Работает с населением", //Facility Staff
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Отдыхает", //Resting at Facility
L"Мертв",
L"Недеесп.",
@@ -2926,12 +2926,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6638,7 +6638,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Штат", //Staff
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Отдых",
L"Ремонт вещей",
L"Ремонт %s", // Vehicle name inserted here
@@ -7029,10 +7029,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|А|п|т|е|ч к|а |п|е|р|в|о|й |п|о|м|о|щ|и",
L"|М|е|д|и|ц|и|нс|к|и|й |н|а|б|о|р",
L"|Б|о|м|б|а |д|л|я |з|а|м|к|о|в",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7047,15 +7048,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7063,10 +7064,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis is a basic field medical kit, containing\nitems required to provide basic medical aid.\n \nIt can be used to bandage wounded characters\nand prevent bleeding.\n \nFor actual healing, use a proper Medical Kit\nand/or plenty of rest.",
L"\n \nThis is a proper medical kit, which can\nbe used in surgery and other serious medicinal\npurposes.\n \nMedical Kits are always required when setting\na character to Doctoring duty.",
L"\n \nThis item can be used to blast open locked\ndoors and containers.\n \nExplosives skill is required to avoid\npremature detonation.\n \nBlowing locks is a relatively easy way of quickly\ngetting through locked doors. However,\nit is very loud, and dangerous to most characters.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/_TaiwaneseText.cpp b/Utils/_TaiwaneseText.cpp
index 02365e8e..d35d8b37 100644
--- a/Utils/_TaiwaneseText.cpp
+++ b/Utils/_TaiwaneseText.cpp
@@ -1638,7 +1638,7 @@ STR16 pAssignmentStrings[] =
L"Trainer", // training a teammate
L"Student", // being trained by someone else
L"Staff", // operating a strategic facility // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Rest", // Resting at a facility // TODO.Translate
L"Dead", // dead
L"Incap.", // abbreviation for incapacitated
@@ -1723,7 +1723,7 @@ STR16 pPersonnelAssignmentStrings[] =
L"Trainer",
L"Student",
L"Facility Staff", // TODO.Translate
- L"Eat", // eating at a facility (cantina etc.) // TODO. Translate
+ L"Eat", // eating at a facility (cantina etc.) // TODO.Translate
L"Resting at Facility", // TODO.Translate
L"Dead",
L"Incap.",
@@ -2927,12 +2927,12 @@ CHAR16 TacticalStr[][ MED_STRING_LENGTH ] =
L"Set detonation time in turns (1 - 4) and defusing frequency (A - D):",
L"Select tripwire hierarchy (1 - 4) and network (A - D):",
- // added by Flugente to display health and poisoning // TODO.Translate
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s",
+ // added by Flugente to display health and poisoning // TODO.Translate
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s",
// added by Flugente to display food status
L"Health: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
- L"Health: %d/%d\n Poison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
+ L"Health: %d/%d\nPoison: %d/%d\nEnergy: %d/%d\nMorale: %s\nWater: %d%s\nFood: %d%s",
};
//Varying helptext explains (for the "Go to Sector/Map" checkbox) what will happen given different circumstances in the "exiting sector" interface.
@@ -6674,7 +6674,7 @@ STR16 gzFacilityAssignmentStrings[]=
{
L"AMBIENT",
L"Staff",
- L"Eat",// TODO. Translate
+ L"Eat",// TODO.Translate
L"Rest",
L"Repair Items",
L"Repair %s", // Vehicle name inserted here
@@ -7066,10 +7066,11 @@ STR16 szUDBGenSecondaryStatsTooltipText[]=
L"|F|i|r|s|t |A|i|d |K|i|t",
L"|M|e|d|i|c|a|l |K|i|t",
L"|L|o|c|k |B|o|m|b",
- L"|D|r|i|n|k",// TODO. Translate
+ L"|D|r|i|n|k",// TODO.Translate
L"|M|e|a|l",
L"|A|m|m|o |B|e|l|t",
L"|A|m|m|o |V|e|s|t",
+ L"|D|e|f|u|s|a|l |K|i|t", // TODO.Translate
};
STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
@@ -7084,15 +7085,15 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis item is electronic in nature, and contains\ncomplex circuitry.\n \nElectronic items are inherently more difficult\nto repair, at least without the ELECTRONICS skill.",
L"\n \nWhen this item is worn on a character's face,\nit will protect them from all sorts of noxious gasses.\n \nNote that some gases are corrosive, and might eat\nright through the mask...",
L"\n \nThis item requires batteries. Without batteries,\nyou cannot activate its primary abilities.\n \nTo use a set of batteries, attach them to\nthis item as you would a scope to a rifle.",
- L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks.",
+ L"\n \nThis item can be used to pick open locked\ndoors or containers.\n \nLockpicking is silent, although it requires\nsubstantial mechanical skill to pick anything\nbut the simplest locks. This item modifies\nthe lockpicking chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to cut through wire fences.\n \nThis allows a character to rapidly move through\nfenced areas, possibly outflanking the enemy!",
- L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools.",
+ L"\n \nThis item can be used to smash open locked\ndoors or containers.\n \nLock-smashing requires substantial strength,\ngenerates a lot of noise, and can easily\ntire a character out. However, it is a good\nway to get through locks without superior skills or\ncomplicated tools. This item improves \nyour chance by ", //JMich_SkillsModifiers: needs to be followed by a number // TODO.Translate
L"\n \nThis item can be used to detect metallic objects\nunder the ground.\n \nNaturally, its primary function is to detect\nmines without the necessary skills to spot them\nwith the naked eye.\n \nMaybe you'll find some buried treasure too.",
L"\n \nThis item can be used to detonate a bomb\nwhich has been set with a remote detonator.\n \nPlant the bomb first, then use the\nRemote Trigger item to set it off when the\ntime is right.",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator can be triggered\nby a (separate) remote device.\n \nRemote Detonators are great for setting traps,\nbecause they only go off when you tell them to.\n \nAlso, you have plenty of time to get away!",
L"\n \nWhen attached to an explosive device and set up\nin the right position, this detonator will count down\nfrom the set amount of time, and explode once the\ntimer expires.\n \nTimer Detonators are cheap and easy to install,\nbut you'll need to time them just right to give\nyourself enough chance to get away!",
L"\n \nThis item contains gasoline (fuel).\n \nIt might come in handy if you ever\nneed to fill up a gas tank...",
- L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty.",
+ L"\n \nThis item contains various tools that can\nbe used to repair other items.\n \nA toolkit item is always required when setting\na character to repair duty. This item modifies\nthe effectiveness of repair by ", //JMich_SkillsModifiers: need to be followed by a number // TODO.Translate
L"\n \nWhen worn in a face-slot, this item provides\nthe ability to spot enemies through walls,\nthanks to their heat signature.",
L"\n \nThis powerful device can be used to scan\nfor enemies using X-rays.\n \nIt will reveal all enemies within a certain radius\nfor a short period of time.\n \nKeep away from reproductive organs!",
L"\n \nThis item contains fresh drinking water.\nUse when thirsty.",
@@ -7100,10 +7101,11 @@ STR16 szUDBGenSecondaryStatsExplanationsTooltipText[]=
L"\n \nThis is a basic field medical kit, containing\nitems required to provide basic medical aid.\n \nIt can be used to bandage wounded characters\nand prevent bleeding.\n \nFor actual healing, use a proper Medical Kit\nand/or plenty of rest.",
L"\n \nThis is a proper medical kit, which can\nbe used in surgery and other serious medicinal\npurposes.\n \nMedical Kits are always required when setting\na character to Doctoring duty.",
L"\n \nThis item can be used to blast open locked\ndoors and containers.\n \nExplosives skill is required to avoid\npremature detonation.\n \nBlowing locks is a relatively easy way of quickly\ngetting through locked doors. However,\nit is very loud, and dangerous to most characters.",
- L"\n \nThis item will still your thirst\nif you drink it.",// TODO. Translate
+ L"\n \nThis item will still your thirst\nif you drink it.",// TODO.Translate
L"\n \nThis item will still your hunger\nif you eat it.",
L"\n \nWith this ammo belt you can\nfeed someone else's MG.",
L"\n \nYou can feed an MG with ammo\nbelts stored in this vest.",
+ L"\n \nThis item improves your trap disarm chance by ", // TODO.Translate
};
STR16 szUDBAdvStatsTooltipText[]=
diff --git a/Utils/Text.h b/Utils/Text.h
index c70ddcee..36b39d3f 100644
--- a/Utils/Text.h
+++ b/Utils/Text.h
@@ -640,8 +640,8 @@ extern STR16 szUDBGenAmmoStatsTooltipText[ 5 ]; // Flugente Overheating: 3
extern STR16 szUDBGenAmmoStatsExplanationsTooltipText[ 5 ]; // Flugente Overheating: 3->4 poison: 4->5
extern STR16 szUDBGenExplosiveStatsTooltipText[ 22 ];
extern STR16 szUDBGenExplosiveStatsExplanationsTooltipText[ 22 ];
-extern STR16 szUDBGenSecondaryStatsTooltipText[ 30 ]; // Flugente Food System: 26 -> 28 external feeding: 28->30
-extern STR16 szUDBGenSecondaryStatsExplanationsTooltipText[ 30 ]; // Flugente Food System: 26 -> 28 external feeding: 28->30
+extern STR16 szUDBGenSecondaryStatsTooltipText[ 31 ]; // Flugente Food System: 26 -> 28 external feeding: 28->30 JMich_SkillsModifiers: 31 for Defusal kit
+extern STR16 szUDBGenSecondaryStatsExplanationsTooltipText[ 31 ]; // Flugente Food System: 26 -> 28 external feeding: 28->30 JMich_SkillsModifiers: 31 for Defusal kit
extern STR16 szUDBAdvStatsTooltipText[ 57 ]; // Flugente Overheating Weapons: 48->56 poison: 56->57
extern STR16 szUDBAdvStatsExplanationsTooltipText[ 57 ]; // Flugente Overheating Weapons: 48->56 poison: 56->57
extern STR16 szUDBAdvStatsExplanationsTooltipTextForWeapons[ 52 ]; // Flugente Overheating Weapons: 48->52